pub enum TerminalStateWatcherRequest {
OnTerminalStateTransitionStarted {
responder: TerminalStateWatcherOnTerminalStateTransitionStartedResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: TerminalStateWatcherControlHandle,
method_type: MethodType,
},
}Expand description
Allows components to be notified when a transition to a terminal state begins. Watchers will be given ‘MAX_TERMINAL_STATE_WATCHER_RESPONSE_TIME_SECONDS’ to return before the system power state is changed. The channel will be used once to send a notification to the watcher. Once the watcher responds or the timeout expires, the channel will be closed by the client of TerminalStateWatcher.
Variants
OnTerminalStateTransitionStarted
Fields
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: TerminalStateWatcherControlHandle
method_type: MethodTypeImplementations
Sourceimpl TerminalStateWatcherRequest
impl TerminalStateWatcherRequest
pub fn into_on_terminal_state_transition_started( self, ) -> Option<TerminalStateWatcherOnTerminalStateTransitionStartedResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL