pub struct ShutdownWatcherRegisterSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ShutdownWatcherRegisterSynchronousProxy
impl ShutdownWatcherRegisterSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ShutdownWatcherRegisterEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ShutdownWatcherRegisterEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn register_watcher(
&self,
watcher: ClientEnd<ShutdownWatcherMarker>,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn register_watcher( &self, watcher: ClientEnd<ShutdownWatcherMarker>, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Registers a watcher to be notified when the Admin.Shutdown method is called.
Once the watcher has been successfully registered with the server, then the request will be completed and the ShutdownWatcherRegister channel will be left open (though a client is free to close it at this time).
If there is an error in registering the watcher, then the ShutdownWatcherRegister channel will be closed without completing the request.
The provided watcher channel will be used at most once to notify the
watcher of an impending shutdown and allow it the chance to respond.
Watchers can unregister by closing their ShutdownWatcher channel.
Sourcepub fn register_terminal_state_watcher(
&self,
watcher: ClientEnd<TerminalStateWatcherMarker>,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn register_terminal_state_watcher( &self, watcher: ClientEnd<TerminalStateWatcherMarker>, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Registers a watcher to be notified when the system begins a transition to a terminal state regardless of the trigger.
The [TerminalStateWatcher] is notified for all reboots, power-offs, and kernel-initiated
shutdowns. It does not provide reasons or options.
Once the watcher has been successfully registered with the server, then the request will be completed and the ShutdownWatcherRegister channel will be left open (though a client is free to close it at this time).
If there is an error in registering the watcher, then the ShutdownWatcherRegister channel will be closed without completing the request.
The provided watcher channel will be used at most once to notify the
watcher of an impending shutdown and allow it the chance to respond.
Watchers can unregister by closing their TerminalStateWatcher channel.