pub struct TerminalStateWatcherMarker;Trait Implementations
Sourceimpl Clone for TerminalStateWatcherMarker
impl Clone for TerminalStateWatcherMarker
Sourcefn clone(&self) -> TerminalStateWatcherMarker
fn clone(&self) -> TerminalStateWatcherMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TerminalStateWatcherMarker
impl Debug for TerminalStateWatcherMarker
Sourceimpl Hash for TerminalStateWatcherMarker
impl Hash for TerminalStateWatcherMarker
Sourceimpl Ord for TerminalStateWatcherMarker
impl Ord for TerminalStateWatcherMarker
Sourcefn cmp(&self, other: &TerminalStateWatcherMarker) -> Ordering
fn cmp(&self, other: &TerminalStateWatcherMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TerminalStateWatcherMarker
impl PartialOrd for TerminalStateWatcherMarker
Sourceimpl ProtocolMarker for TerminalStateWatcherMarker
impl ProtocolMarker for TerminalStateWatcherMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) TerminalStateWatcher"
const DEBUG_NAME: &'static str = "(anonymous) TerminalStateWatcher"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = TerminalStateWatcherProxy
type Proxy = TerminalStateWatcherProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = TerminalStateWatcherRequestStream
type RequestStream = TerminalStateWatcherRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = TerminalStateWatcherSynchronousProxy
type SynchronousProxy = TerminalStateWatcherSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for TerminalStateWatcherMarker
impl Eq for TerminalStateWatcherMarker
impl StructuralPartialEq for TerminalStateWatcherMarker